@@ -46,6 +46,14 @@ def classify_type(cmpt, cmpt_type='unknown'):
     hybrid = cmpt.find('div', {'class':'ifM9O'})
     twitter = cmpt.find_previous().text == "Twitter Results"
 
+    # Checks a g-section for a specific id to classify as top stories as not all
+    # top stories have an h3 tag
+    if g_section:
+        car = g_section.find('g-scrolling-carousel')
+        if car:
+            if 'class' in car.attrs and car.attrs['class'][0] == 'F8yfEe':
+                cmpt_type = 'top_stories'
+
     # Check `h2.text` for string matches
     if h2:
         for text, ctype in h2_matches.items():
@@ -58,7 +66,6 @@ def classify_type(cmpt, cmpt_type='unknown'):
             if h3.text.startswith(text):
                 cmpt_type = ctype
 
-
     # Twitter subtype
     
     if twitter or cmpt_type == 'twitter':
