@@ -1,4 +1,3 @@
-import pandas as pd
 from .ads import parse_ads
 from .knowledge import parse_knowledge_panel
 from .general import parse_general_results
@@ -20,14 +19,14 @@ from .footer import parse_footer
 
 # Component details dataframe
 columns = ['type', 'func', 'label']
-components = pd.DataFrame([
+components = [
     ('ad', parse_ads, 'Ad'),
     ('knowledge', parse_knowledge_panel, 'Knowledge'),
     ('general', parse_general_results, 'General'),
     ('general_questions', parse_general_questions, 'General Questions'),
     ('general_menu', parse_general_results, 'General Submenu'),
     ('available_on', parse_available_on, 'Available On'),
-    ('top_stories', parse_top_stories, 'Top Stories'), 
+    ('top_stories', parse_top_stories, 'Top Stories'),
     ('latest_from', parse_latest_from, 'Latest From'),
     ('view_more_news', parse_view_more_news, 'View More News'),
     ('news_quotes', parse_news_quotes, 'News Quotes'),
@@ -41,10 +40,10 @@ components = pd.DataFrame([
     ('twitter_result', parse_twitter_result, 'Twitter Result'),
     ('scholarly_articles', parse_scholarly_articles, 'Scholar Articles'),
     ('footer', parse_footer, 'Footer')
-], columns=columns)
+]
 
-# dict[type] = function
-type_functions = components.set_index('type')['func'].to_dict()
+# Format {type: function}
+type_functions = {i[0]:i[1] for i in components}
 
-# dict[type] = label
-type_labels = components.set_index('type')['label'].to_dict()
+# Format {type: label}
+type_labels = {i[0]:i[2] for i in components}
